Params

Struct Params 

pub struct Params<'k, 'v> { /* private fields */ }
Matcher parameters.

This is a thin wrapper around the Params data type of the matchit crate to shield against unforeseen changes in the crate’s implementation.

Note that Params should be used without lifetime parameters, as it’s designed to be used in a context where lifetimes are irrelevant, i.e., in the signature of an Action, ensuring that third-party integrations don’t break when the implementation changes, albeit unlikely.

Implementations

Source

impl<'k, 'v> Params<'k, 'v>

pub fn get<K>(&self, key: K) -> Option<&'v str>
where K: AsRef<str>,

Returns the value for the given key.

Examples
use zapient::http::{Request, Response, Status};
use zapient::router::{Router, Params};

// Create router and add route
let router = Router::default()
    .get("/coffee/{kind}", |req: Request, params: Params| {
        if let Some(kind) = params.get("kind") {
            Response::default() // Handle request
        } else {
            Response::new().status(Status::BadRequest)
        }
    });
pub fn contains<K>(&self, key: K) -> bool
where K: AsRef<str>,

Returns whether the parameter is contained.

Examples
use zapient::http::{Request, Response, Status};
use zapient::router::{Router, Params};

// Create router and add route
let router = Router::default()
    .get("/coffee/{kind}", |req: Request, params: Params| {
        if params.contains("kind") {
            Response::default() // Handle request
        } else {
            Response::new().status(Status::BadRequest)
        }
    });
pub fn iter(&self) -> ParamsIter<'_, 'k, 'v>

Returns an iterator over all parameters.

Examples
use zapient::http::{Request, Response};
use zapient::router::{Router, Params};

// Create router and add route
let router = Router::default()
    .get("/coffee/{kind}", |req: Request, params: Params| {
        for (key, value) in params.iter() {
            println!("{key}: {value}");
        }
        Response::default() // Handle request
    });
Source

impl Params<'_, '_>

pub fn len(&self) -> usize

Returns the number of parameters.

pub fn is_empty(&self) -> bool

Returns whether the parameter map is empty.